@@ -1,7 +1,7 @@
 """\nplotext plots directly on terminal"""
     
 __name__ = "plotext"
-__version__ = "5.2.7"
+__version__ = "5.2.8"
 
 from ._core import *
-from .plotext_cli import build_parser
+#from .plotext_cli import build_parser # not sure why this line was here
