@@ -128,10 +128,10 @@ class build_class():
         col_title = col_center if self.xlabel[1] is None else 0
         row_title = row_end + self.xaxes[1] + height_xlabels[1]
         alignment_title = "center" if self.xlabel[1] is None else "left"
-        self.matrix.add_horizontal_string(col_title, row_title, self.title, *ticks_colors, alignment = alignment_title, check_space = True) if self.title and height > 0 is not None else None
+        self.matrix.add_horizontal_string(col_title, row_title, self.title, *ticks_colors, alignment = alignment_title, check_space = True) if self.title and height > 0 else None
 
         # Add Upper X Label
-        self.matrix.add_horizontal_string(col_center, row_title, self.xlabel[1], *ticks_colors, alignment = "center", check_space = True) if self.xlabel[1] and height > 0 is not None else None
+        self.matrix.add_horizontal_string(col_center, row_title, self.xlabel[1], *ticks_colors, alignment = "center", check_space = True) if self.xlabel[1] and height > 0 else None
 
         # Add Lower X Ticks
         row_xticks = min(row_start - self.xaxes[0] - 1, height - 1)
@@ -178,13 +178,13 @@ class build_class():
         self.matrix.add_horizontal_string(col_start, row_start - 1, xaxis, self.ticks_color) if self.xaxes[0] and height_canvas >= -1 else None
 
         # Add Left Y Label
-        self.matrix.add_horizontal_string(0, 0, self.ylabel[0], *ticks_colors, check_space = True) if self.ylabel[0] and height > 0 is not None else None
+        self.matrix.add_horizontal_string(0, 0, self.ylabel[0], *ticks_colors, check_space = True) if self.ylabel[0] and height > 0 else None
         
         # Add Right Y Label 
-        self.matrix.add_horizontal_string(width - 1, 0, self.ylabel[1], *ticks_colors, check_space = True, alignment = "right") if self.ylabel[1] and height > 0 is not None else None
+        self.matrix.add_horizontal_string(width - 1, 0, self.ylabel[1], *ticks_colors, check_space = True, alignment = "right") if self.ylabel[1] and height > 0 else None
 
         # Add Lower X Label 
-        self.matrix.add_horizontal_string(col_center, 0, self.xlabel[0], *ticks_colors, alignment = "center", check_space = True) if self.xlabel[0] and height > 0 is not None else None
+        self.matrix.add_horizontal_string(col_center, 0, self.xlabel[0], *ticks_colors, alignment = "center", check_space = True) if self.xlabel[0] and height > 0 else None
 
         # Add Grid Lines
         hline = '─' * width_canvas
@@ -247,14 +247,14 @@ class build_class():
 
         # Add Legend Side Symbols
         side = [ut.space + ut.side_symbols[(self.xside[s], self.yside[s])] for s in Signals if labelled(s)]
-        side_test = not (ut.no_duplicates(side) == [' L']); S = 2 if side_test else 0;
+        side_test = not (ut.no_duplicates(side) == [' L']) and not l == 1; S = 2 if side_test else 0;
         legend_test = width_canvas >= S + 3 + L and height_canvas >= len(labels)
         [self.matrix.add_horizontal_string(col_start, row_end - 1 - s, side[s], self.ticks_color, self.ticks_style) for s in range(l)] if legend_test and side_test else None
 
         # Add Legend Markers
         take_3 = lambda data: (data[ : 3] * 3)[ : 3]
         marker = [take_3(self.marker[s]) for s in Signals if labelled(s)]
-        replace_hd_marker = lambda marker: '🬗' if marker == 'fhd' else '▞' if marker == 'hd' else marker
+        replace_hd_marker = lambda marker: ut.hd_symbols[marker] if marker in ut.hd_symbols else marker
         marker = [[ut.space] + list(map(replace_hd_marker, el)) for el in marker]
         color =  [[ut.no_color] + take_3(c[s]) for s in Signals if labelled(s)]
         style =  [[ut.no_color] + take_3(st[s]) for s in Signals if labelled(s)]
