@@ -80,8 +80,8 @@ class _figure_class():
 ##############################################
 
     def _set_slots_max(self, width = None, height = None):
-        self._rows_max = (height + 1) // 3 
-        self._cols_max = (width + 1) // 3 
+        self._rows_max = height # (height + 1) // 3 
+        self._cols_max = width # (width + 1) // 3 
         self._slots_max = [self._rows_max, self._cols_max]
 
     def _set_slots(self, rows = None, cols = None):
@@ -95,7 +95,7 @@ class _figure_class():
         self._no_plots = 0 in self._slots #or self._is_master
         
     def _set_subplots(self):
-        self.subfig = [[_figure_class(self._master, self._parent) for col in self._Cols] for row in self._Rows]
+        self.subfig = [[_figure_class(self._master, self) for col in self._Cols] for row in self._Rows]
         
     def _get_subplot(self, row = None, col = None):
         return self.subfig[row - 1][col - 1] if row in self._Rows and col in self._Cols else self._master._dummy
@@ -214,8 +214,8 @@ class _figure_class():
     def plot(self, *args, xside = None, yside = None, marker = None, color = None, style = None, fillx = None, filly = None, label = None):
         self._draw(*args, xside = xside, yside = yside, lines = True, marker = marker, color = color,  fillx = fillx, filly = filly, label = label)
 
-    def candlestick(self, dates, data, orientation = None, colors = None, label = None):
-        self.monitor.draw_candlestick(dates, data, orientation = orientation, colors = colors, label = label) if self._no_plots else [[self._get_subplot(row, col).candlestick(dates, data, orientation = orientation, colors = colors, label = label) for col in self._Cols] for row in self._Rows]
+    def candlestick(self, dates, data, xside = None, yside = None, orientation = None, colors = None, label = None):
+        self.monitor.draw_candlestick(dates, data, xside = xside, yside = yside, orientation = orientation, colors = colors, label = label) if self._no_plots else [[self._get_subplot(row, col).candlestick(dates, data, orientation = orientation, colors = colors, label = label) for col in self._Cols] for row in self._Rows]
         
     def bar(self, *args, xside = None, yside = None, marker = None, color = None, fill = None, width = None, orientation = None, label = None, minimum = None, reset_ticks = None):
         self.monitor.draw_bar(*args, xside = xside, yside = yside, marker = marker, color = color, fill = fill, width = width, orientation = orientation, label = label, minimum = minimum, reset_ticks = reset_ticks) if self._no_plots else [[self._get_subplot(row, col).bar(*args, xside = xside, yside = yside, marker = marker, color = color, fill = fill, width = width, orientation = orientation, label = label, minimum = minimum, reset_ticks = reset_ticks) for col in self._Cols] for row in self._Rows]
