@@ -122,6 +122,8 @@ class monitor_class(build_class):
         self.ylabel[pos] = self.set_label(label)
         
     def set_xlim(self, left = None, right = None, xside = None):
+        left = self.date.string_to_time(left) if isinstance(left, str) else left
+        right = self.date.string_to_time(right) if isinstance(right, str) else right
         left = None if left is None else float(left)
         right = None if right is None else float(right)
         xlim = [left, right]
@@ -130,6 +132,8 @@ class monitor_class(build_class):
         self.xlim[pos] = xlim
 
     def set_ylim(self, lower = None, upper = None, yside = None):
+        lower = self.date.string_to_time(lower) if isinstance(lower, str) else lower
+        upper = self.date.string_to_time(upper) if isinstance(upper, str) else upper
         lower = None if lower is None else float(lower)
         upper = None if upper is None else float(upper)
         ylim = [lower, upper]
@@ -363,7 +367,7 @@ class monitor_class(build_class):
     
     def check_marker(self, marker = None):
         marker = None if marker is None else str(marker)
-        marker = ut.plot_marker if marker is None else marker
+        marker = self.default.marker if marker is None else marker
         marker = ut.marker_codes[marker] if marker in ut.marker_codes else marker
         marker = marker if marker in ut.hd_symbols else marker[0]
         return marker
@@ -494,7 +498,7 @@ class monitor_class(build_class):
                       minimum = None,
                       reset_ticks = False)
 
-    def draw_candlestick(self, dates, data, orientation = None, colors = None, label = None):
+    def draw_candlestick(self, dates, data, xside = None, yside = None, orientation = None, colors = None, label = None):
         orientation = self.check_orientation(orientation, 1)
         markers = ['sd', '│', '─'] #if markers is None else markers
         colors = ['green', 'red'] if colors is None else colors
@@ -509,13 +513,13 @@ class monitor_class(build_class):
             m, M = min(o, c), max(o, c)
             lab = label if i == 0 else None
             if orientation in ['v', 'vertical']:
-                self.draw([d, d], [M, h], color = color, marker = markers[1], lines = True)
-                self.draw([d, d], [l, m], color = color, marker = markers[1], lines = True)
-                self.draw([d, d], [m, M], color = color, marker = markers[0], lines = True, label = lab)
+                self.draw([d, d], [M, h], xside = xside, yside = yside, color = color, marker = markers[1], lines = True)
+                self.draw([d, d], [l, m], xside = xside, yside = yside, color = color, marker = markers[1], lines = True)
+                self.draw([d, d], [m, M], xside = xside, yside = yside, color = color, marker = markers[0], lines = True, label = lab)
             elif orientation in ['h', 'horizontal']:
-                self.draw([M, h], [d, d], color = color, marker = markers[2], lines = True)
-                self.draw([l, m], [d, d], color = color, marker = markers[2], lines = True)
-                self.draw([m, M], [d, d], color = color, marker = markers[0], lines = True, label = lab)
+                self.draw([M, h], [d, d], xside = xside, yside = yside, color = color, marker = markers[2], lines = True)
+                self.draw([l, m], [d, d], xside = xside, yside = yside, color = color, marker = markers[2], lines = True)
+                self.draw([m, M], [d, d], xside = xside, yside = yside, color = color, marker = markers[0], lines = True, label = lab)
         
 ##############################################
 ###########    Plotting Tools    #############
